# nisardev
Tools for nisar cal/val activities and cryo notebooks

For examples of how this library is used refer to notebooks in https://github.com/fastice/GrIMPNotebooks

## Installation

In an existing python virtual environment: `pip install https://github.com/fastice/nisardev.git@main`
